summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/tclsqlite.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/tclsqlite.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/tclsqlite.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/kexi/3rdparty/kexisql3/src/tclsqlite.c b/kexi/3rdparty/kexisql3/src/tclsqlite.c
index 4387e2f7..51bde4ee 100644
--- a/kexi/3rdparty/kexisql3/src/tclsqlite.c
+++ b/kexi/3rdparty/kexisql3/src/tclsqlite.c
@@ -921,7 +921,7 @@ static int DbObjCmd(void *cd, Tcl_Interp *interp, int objc,Tcl_Obj *const*objv){
** as column separators. If a column contains a null string, or the
** value of NULLINDICATOR, a NULL is inserted for the column.
** conflict-algorithm is one of the sqlite conflict algorithms:
** rollback, abort, fail, ignore, tqreplace
** On success, return the number of lines processed, not necessarily same
** as 'db changes' due to conflict-algorithm selected.
**
@@ -982,10 +982,10 @@ static int DbObjCmd(void *cd, Tcl_Interp *interp, int objc,Tcl_Obj *const*objv){
sqlite3StrICmp(zConflict, "abort" ) != 0 &&
sqlite3StrICmp(zConflict, "fail" ) != 0 &&
sqlite3StrICmp(zConflict, "ignore" ) != 0 &&
- sqlite3StrICmp(zConflict, "tqreplace" ) != 0 ) {
+ sqlite3StrICmp(zConflict, "replace" ) != 0 ) {
Tcl_AppendResult(interp, "Error: \"", zConflict,
"\", conflict-algorithm must be one of: rollback, "
- "abort, fail, ignore, or tqreplace", 0);
+ "abort, fail, ignore, or replace", 0);
return TCL_ERROR;
}
zSql = sqlite3_mprintf("SELECT * FROM '%q'", zTable);
@@ -1822,7 +1822,7 @@ static int DbObjCmd(void *cd, Tcl_Interp *interp, int objc,Tcl_Obj *const*objv){
** DBNAME that is used to control that connection. The database
** connection is deleted when the DBNAME command is deleted.
**
-** The second argument is the name of the directory that tqcontains
+** The second argument is the name of the directory that contains
** the sqlite database that is to be accessed.
**
** For testing purposes, we also support the following:
@@ -921,7 +921,7 @@ static int DbObjCmd(void *cd, Tcl_Interp *interp, int objc,Tcl_Obj *const*objv){
** value of NULLINDICATOR, a NULL is inserted for the column.
** conflict-algorithm is one of the sqlite conflict algorithms:
- ** rollback, abort, fail, ignore, tqreplace
+ ** rollback, abort, fail, ignore, replace
** On success, return the number of lines processed, not necessarily same
** as 'db changes' due to conflict-algorithm selected.